==> gcc-java-4.1.1.tar.bz2: gcc-4.1.1/libjava/classpath/java/security/cert/CertPathValidatorSpi.java <==
/* CertPathValidatorSpi -- cert path validator service provider interface
   Copyright (C) 2003 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.
 
GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.security.cert;

/**
 * The <i>service provider interface</i> (<b>SPI</b>) for the {@link
 * CertPathValidator} class. Providers implementing certificate path
 * validators must subclass this class and implement its abstract
 * methods.
 */
public abstract class CertPathValidatorSpi
{

  // Constructor.
  // ------------------------------------------------------------------------

  /**
   * Default constructor.
   */
  public CertPathValidatorSpi()
  {
    super();
  }

  // Abstract methods.
  // ------------------------------------------------------------------------

  /**
   * Attempt to validate a certificate path.
   *
   * @param certPath The path to validate.
   * @param params   The algorithm-specific parameters.
   * @return The result of this validation attempt.
   * @throws CertPathValidatorException If the certificate path cannot
   * be validated.
   * @throws InvalidAlgorithmParameterException If this implementation
   * rejects the specified parameters.
   */
  public abstract CertPathValidatorResult
  engineValidate(CertPath certPath, CertPathParameters params)
  throws CertPathValidatorException,
         java.security.InvalidAlgorithmParameterException;
}

==> gcc-java-4.4.5.tar.bz2: gcc-4.4.5/libjava/classpath/java/security/cert/CertPathValidatorSpi.java <==
/* CertPathValidatorSpi -- cert path validator service provider interface
   Copyright (C) 2003 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.
 
GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.security.cert;

import java.security.InvalidAlgorithmParameterException;

/**
 * The <i>service provider interface</i> (<b>SPI</b>) for the {@link
 * CertPathValidator} class. Providers implementing certificate path
 * validators must subclass this class and implement its abstract
 * methods.
 */
public abstract class CertPathValidatorSpi
{

  // Constructor.
  // ------------------------------------------------------------------------

  /**
   * Default constructor.
   */
  public CertPathValidatorSpi()
  {
    super();
  }

  // Abstract methods.
  // ------------------------------------------------------------------------

  /**
   * Attempt to validate a certificate path.
   *
   * @param certPath The path to validate.
   * @param params   The algorithm-specific parameters.
   * @return The result of this validation attempt.
   * @throws CertPathValidatorException If the certificate path cannot
   * be validated.
   * @throws InvalidAlgorithmParameterException If this implementation
   * rejects the specified parameters.
   */
  public abstract CertPathValidatorResult
  engineValidate(CertPath certPath, CertPathParameters params)
  throws CertPathValidatorException,
         InvalidAlgorithmParameterException;
}
